@@ -4,7 +4,7 @@ use std::{
     ffi::OsStr,
     fs,
     ops::Deref,
-    path::PathBuf,
+    path::{Path, PathBuf},
     rc::Rc,
     sync::Arc,
 };
@@ -198,7 +198,8 @@ impl LmdbWasmTestBuilder {
     ) -> Self {
         Self::initialize_logging();
         let page_size = *OS_PAGE_SIZE;
-        let global_state_dir = Self::create_and_get_global_state_dir(data_dir);
+        let global_state_dir = Self::global_state_dir(data_dir);
+        Self::create_global_state_dir(&global_state_dir);
         let environment = Arc::new(
             LmdbEnvironment::new(
                 &global_state_dir,
@@ -261,10 +262,22 @@ impl LmdbWasmTestBuilder {
         data_dir: &T,
         engine_config: EngineConfig,
         post_state_hash: Blake2bHash,
+    ) -> Self {
+        let global_state_path = Self::global_state_dir(data_dir);
+        Self::open_raw(global_state_path, engine_config, post_state_hash)
+    }
+
+    /// Creates a new instance of builder using the supplied configurations, opening wrapped LMDBs
+    /// (e.g. in the Trie and Data stores) rather than creating them.
+    /// Differs from `open` in that it doesn't append `GLOBAL_STATE_DIR` to the supplied path.
+    pub fn open_raw<T: AsRef<Path>>(
+        global_state_dir: T,
+        engine_config: EngineConfig,
+        post_state_hash: Blake2bHash,
     ) -> Self {
         Self::initialize_logging();
         let page_size = *OS_PAGE_SIZE;
-        let global_state_dir = Self::create_and_get_global_state_dir(data_dir);
+        Self::create_global_state_dir(&global_state_dir);
         let environment = Arc::new(
             LmdbEnvironment::new(
                 &global_state_dir,
@@ -298,15 +311,19 @@ impl LmdbWasmTestBuilder {
         }
     }
 
-    fn create_and_get_global_state_dir<T: AsRef<OsStr> + ?Sized>(data_dir: &T) -> PathBuf {
-        let global_state_path = {
-            let mut path = PathBuf::from(data_dir);
-            path.push(GLOBAL_STATE_DIR);
-            path
-        };
-        fs::create_dir_all(&global_state_path)
-            .unwrap_or_else(|_| panic!("Expected to create {}", global_state_path.display()));
-        global_state_path
+    fn create_global_state_dir<T: AsRef<Path>>(global_state_path: T) {
+        fs::create_dir_all(&global_state_path).unwrap_or_else(|_| {
+            panic!(
+                "Expected to create {}",
+                global_state_path.as_ref().display()
+            )
+        });
+    }
+
+    fn global_state_dir<T: AsRef<OsStr> + ?Sized>(data_dir: &T) -> PathBuf {
+        let mut path = PathBuf::from(data_dir);
+        path.push(GLOBAL_STATE_DIR);
+        path
     }
 }
 
@@ -403,6 +420,18 @@ where
         Err(format!("{:?}", query_result))
     }
 
+    pub fn query_dictionary_item(
+        &self,
+        maybe_post_state: Option<Blake2bHash>,
+        dictionary_seed_uref: URef,
+        dictionary_item_key: &str,
+    ) -> Result<StoredValue, String> {
+        let dictionary_address =
+            Key::dictionary(dictionary_seed_uref, dictionary_item_key.as_bytes());
+        let empty_path: Vec<String> = vec![];
+        self.query(maybe_post_state, dictionary_address, &empty_path)
+    }
+
     pub fn query_with_proof(
         &self,
         maybe_post_state: Option<Blake2bHash>,
@@ -574,7 +603,7 @@ where
         }
     }
 
-    /// Expects a successful run and caches transformations
+    /// Expects a successful run
     pub fn expect_success(&mut self) -> &mut Self {
         // Check first result, as only first result is interesting for a simple test
         let exec_results = self
@@ -587,13 +616,34 @@ where
 
         if exec_result.is_failure() {
             panic!(
-                "Expected successful execution result, but instead got: {:?}",
+                "Expected successful execution result, but instead got: {:#?}",
                 exec_results,
             );
         }
         self
     }
 
+    /// Expects a failed run
+    pub fn expect_failure(&mut self) -> &mut Self {
+        // Check first result, as only first result is interesting for a simple test
+        let exec_results = self
+            .exec_results
+            .last()
+            .expect("Expected to be called after run()");
+        let exec_result = exec_results
+            .get(0)
+            .expect("Unable to get first deploy result");
+
+        if exec_result.is_success() {
+            panic!(
+                "Expected failed execution result, but instead got: {:?}",
+                exec_results,
+            );
+        }
+
+        self
+    }
+
     pub fn is_error(&self) -> bool {
         let exec_results = self
             .exec_results
